@@ -4,7 +4,7 @@ use v6;
 
 =head1 NAME
 
-JSON::Name - Provide a trait (and Attribute role) for JSON Marshal/Unmarshal where the JSON names aren't Perl identifiers
+JSON::Name - Provide a trait (and Attribute role) for JSON Marshal/Unmarshal where the JSON names aren't Raku identifiers
 
 =head1 SYNOPSIS
 
@@ -28,7 +28,7 @@ L<JSON::Marshal|https://github.com/jonathanstowe/JSON-Marshal> and
 L<JSON::Unmarshal|https://github.com/tadzik/JSON-Unmarshal> in order to
 save duplication, it is intended to store a separate JSON name for an
 attribute where the name of the JSON attribute might be changed, either
-for aesthetic reasons or the name is not a valid Perl identifier. It will
+for aesthetic reasons or the name is not a valid Raku identifier. It will
 of course also be needed in classes thar are going to use JSON::Marshal
 or JSON::Unmarshal for serialisation/de-serialisation.
 
@@ -38,7 +38,7 @@ Of course it could be used in other modules for a similar purpose.
 
 
 
-module JSON::Name:ver<0.0.4>:auth<github:jonathanstowe> {
+module JSON::Name:ver<0.0.5>:auth<github:jonathanstowe> {
     role NamedAttribute {
         has Str $.json-name is rw;
     }
@@ -49,4 +49,4 @@ module JSON::Name:ver<0.0.4>:auth<github:jonathanstowe> {
     }
 
 }
-# vim: expandtab shiftwidth=4 ft=perl6
+# vim: expandtab shiftwidth=4 ft=raku
